@@ -1,13 +1,17 @@
 similarity.variables <-
-function(data, associationFun=association, check.psd=TRUE, make.psd=TRUE){
+function(data, method=c("associationMeasures", "distcor"), associationFun=association, check.psd=TRUE, make.psd=TRUE){
 # data: data.frame of original data 
-# associationFun: function that calculates association measure for each pair of variables
+# method: method to calculate distances: combination of association measures ("associationMeasures") or distance correlation ("distcor")
+# associationFun: function that calculates association measure for each pair of variables in case of method="association"
 # check.psd: check if resulting similarity matrix S is positive semi-definite?
 # make.psd: if S is not p.s.d., shall it be transformed to be p.s.d.? (only done if also check.psd=TRUE)
   
+  method <- match.arg(method)
+  
   #n <- nrow(data)
   p <- ncol(data)
   
+  if(method == "associationMeasures"){
   S <- matrix(0, nrow=p, ncol=p)
   for(i in 1:p){
     for(j in 1:p){
@@ -37,6 +41,12 @@ function(data, associationFun=association, check.psd=TRUE, make.psd=TRUE){
       }
     }
   }
+  }
   
+  else if(method == "distcor"){
+    dcm <- dcormat_bc(data)  
+    S <- sign(dcm) * sqrt(abs(dcm))
+  }
+
   return(as.matrix(S))
 }
